==> haskell-tls-session-manager-0.0.0.1-9-i686.pkg.tar.xz: usr/share/haskell/register/haskell-tls-session-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tls-session-manager
version: 0.0.0.1
id: tls-session-manager-0.0.0.1-ZbJ3zoZeou62LCHjURKzg
key: tls-session-manager-0.0.0.1-ZbJ3zoZeou62LCHjURKzg
license: BSD3
maintainer: kazu@iij.ad.jp
synopsis: In-memory TLS session manager
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance
category: Web
author: Kazu Yamamoto
exposed: True
indefinite: False
exposed-modules:
    Network.TLS.SessionManager
abi: 675c9168387b57a76efd0374f2826635
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/tls-session-manager-0.0.0.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/tls-session-manager-0.0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/tls-session-manager-0.0.0.1
hs-libraries: HStls-session-manager-0.0.0.1-ZbJ3zoZeou62LCHjURKzg
depends:
    base-4.10.0.0 auto-update-0.1.4-GZpbAgyETDJHs1aXX3MWAW
    clock-0.7.2-9fV7rV7wNUo6v6mDurfiVg
    psqueues-0.2.3.0-CwAzjDDqYyqJcuhMywfrrv
    tls-1.4.0-DUjRpAMZEHBIySIXtFteXe
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             auto-update-0.1.4-GZpbAgyETDJHs1aXX3MWAW=05dc294e863651d9a465fdf5002212e6
             clock-0.7.2-9fV7rV7wNUo6v6mDurfiVg=1e1baf841d0fcad1b9eca88e567ce03e
             psqueues-0.2.3.0-CwAzjDDqYyqJcuhMywfrrv=c9472969e2d5d69948499c4e01f48a1d
             tls-1.4.0-DUjRpAMZEHBIySIXtFteXe=3640de764ce719572b5f1552b01ce71e
haddock-interfaces: /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock
haddock-html: /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tls-session-manager-0.0.0.1-12-i686.pkg.tar.xz: usr/share/haskell/register/haskell-tls-session-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tls-session-manager
version: 0.0.0.1
id: tls-session-manager-0.0.0.1-Iq3PimOURetJQU9mLNdTLS
key: tls-session-manager-0.0.0.1-Iq3PimOURetJQU9mLNdTLS
license: BSD3
maintainer: kazu@iij.ad.jp
synopsis: In-memory TLS session manager
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance
category: Web
author: Kazu Yamamoto
exposed: True
indefinite: False
exposed-modules:
    Network.TLS.SessionManager
abi: e3ccfb9cad112e3b19d9a7e60cb873d9
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/tls-session-manager-0.0.0.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/tls-session-manager-0.0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/tls-session-manager-0.0.0.1
hs-libraries: HStls-session-manager-0.0.0.1-Iq3PimOURetJQU9mLNdTLS
depends:
    base-4.10.0.0 auto-update-0.1.4-GZpbAgyETDJHs1aXX3MWAW
    clock-0.7.2-9fV7rV7wNUo6v6mDurfiVg
    psqueues-0.2.4.0-F00pVfPVt6dDn5IhRLjD8k
    tls-1.4.0-31ZRwpEukM6Jnw4JDFykbI
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             auto-update-0.1.4-GZpbAgyETDJHs1aXX3MWAW=05dc294e863651d9a465fdf5002212e6
             clock-0.7.2-9fV7rV7wNUo6v6mDurfiVg=1e1baf841d0fcad1b9eca88e567ce03e
             psqueues-0.2.4.0-F00pVfPVt6dDn5IhRLjD8k=0511df6c1df7f83df998da2914260b06
             tls-1.4.0-31ZRwpEukM6Jnw4JDFykbI=9bc89678995e74c71ba5c4956aa98062
haddock-interfaces: /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock
haddock-html: /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
